pub struct AppBuilder<C>where
C: AppConfig,{ /* private fields */ }Expand description
Builder for App.
The builder is the composition root for configuration validation, component registration, dependency injection, provider registration, and lifecycle hook ordering.
Implementations
Sourceimpl<C> AppBuilder<C>where
C: AppConfig,
impl<C> AppBuilder<C>where
C: AppConfig,
Sourcepub fn new(config: C) -> AppBuilder<C>
pub fn new(config: C) -> AppBuilder<C>
Create a new builder with the given application configuration.
Sourcepub fn with_graceful_timeout(self, timeout: Duration) -> AppBuilder<C>
pub fn with_graceful_timeout(self, timeout: Duration) -> AppBuilder<C>
Set the graceful shutdown timeout.
Sourcepub fn with_component(self, component: Arc<dyn Component>) -> AppBuilder<C>
pub fn with_component(self, component: Arc<dyn Component>) -> AppBuilder<C>
Register a component to be started and stopped by the app lifecycle.
Sourcepub fn with_container(self, container: Arc<Container>) -> AppBuilder<C>
pub fn with_container(self, container: Arc<Container>) -> AppBuilder<C>
Use an existing typed DI container as the application container.
Sourcepub fn with_lifecycle_event_bus(
self,
lifecycle_events: EventBus<LifecycleEvent>,
) -> AppBuilder<C>
pub fn with_lifecycle_event_bus( self, lifecycle_events: EventBus<LifecycleEvent>, ) -> AppBuilder<C>
Use an existing bounded lifecycle event bus.
Sourcepub fn with_dependency<T>(self, dependency: Arc<T>) -> AppBuilder<C>
pub fn with_dependency<T>(self, dependency: Arc<T>) -> AppBuilder<C>
Register a typed dependency in the application DI container.
Sourcepub fn with_provider<P>(self, provider: Arc<P>) -> AppBuilder<C>
pub fn with_provider<P>(self, provider: Arc<P>) -> AppBuilder<C>
Register a provider implementation in the application DI container.
Sourcepub fn before_start<F, Fut>(self, hook: F) -> AppBuilder<C>
pub fn before_start<F, Fut>(self, hook: F) -> AppBuilder<C>
Register a hook called before components start.
Sourcepub fn after_start<F, Fut>(self, hook: F) -> AppBuilder<C>
pub fn after_start<F, Fut>(self, hook: F) -> AppBuilder<C>
Register a hook called after components start and readiness checks pass.
Sourcepub fn before_stop<F, Fut>(self, hook: F) -> AppBuilder<C>
pub fn before_stop<F, Fut>(self, hook: F) -> AppBuilder<C>
Register a hook called before components stop.
Sourcepub fn after_stop<F, Fut>(self, hook: F) -> AppBuilder<C>
pub fn after_stop<F, Fut>(self, hook: F) -> AppBuilder<C>
Register a hook called after components stop.