pub struct TaskHandle<O>{
pub id: Uuid,
/* private fields */
}Expand description
Handle returned to a caller after submitting a task to the pool.
result()awaits the final task output.events()returns a broadcast receiver for intermediateEvents.cancel()requests cooperative cancellation.
Fields
id: UuidUnique identifier assigned to this task by the pool.
Implementations
Sourceimpl<O> TaskHandle<O>
impl<O> TaskHandle<O>
Sourcepub fn events(&self) -> Receiver<Event<O>>
pub fn events(&self) -> Receiver<Event<O>>
Get a new broadcast receiver for intermediate events.
Sourcepub fn cancel_token(&self) -> CancellationToken
pub fn cancel_token(&self) -> CancellationToken
Clone the cancellation token so it can be stored separately
(e.g., for cancelling after the handle is consumed by result()).