#[non_exhaustive]pub enum PromptError {
MissingVariable(String),
MissingField(&'static str),
InvalidVersion {
version: String,
source: Error,
},
AlreadyRegistered {
name: String,
version: Version,
},
NotFound {
name: String,
version: Version,
},
NameNotFound(String),
}Expand description
Errors returned by prompt rendering, construction, and registry lookup.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
MissingVariable(String)
A named variable required by the template was absent from the render context.
MissingField(&'static str)
A builder was missing a required field.
InvalidVersion
A prompt version string was not valid semver.
AlreadyRegistered
A registry entry already exists.
NotFound
A registry entry was not found.
NameNotFound(String)
No versions exist for a prompt name.