pub struct App<S, C> { /* private fields */ }Expand description
Application orchestrator with typestate lifecycle.
Valid transitions are compile-time scoped:
AppBuilder::build() -> App<Built, C>
App<Built, C>::start() -> App<Started, C>
App<Started, C>::stop() -> App<Stopped, C>Implementations
Sourceimpl<C> App<Built, C>where
C: AppConfig,
impl<C> App<Built, C>where
C: AppConfig,
Sourcepub fn builder(config: C) -> AppBuilder<C>
pub fn builder(config: C) -> AppBuilder<C>
Create an AppBuilder.
Sourceimpl<C> App<Built, C>
impl<C> App<Built, C>
Sourcepub fn lifecycle_event_bus(&self) -> EventBus<LifecycleEvent>
pub fn lifecycle_event_bus(&self) -> EventBus<LifecycleEvent>
Return the bounded lifecycle event bus used by this app.
Sourcepub fn shutdown_token(&self) -> CancellationToken
pub fn shutdown_token(&self) -> CancellationToken
Clone the shutdown token to share with long-running tasks.
Sourcepub fn before_start<F, Fut>(self, hook: F) -> App<Built, C>
pub fn before_start<F, Fut>(self, hook: F) -> App<Built, C>
Register a hook called before components start.
Sourcepub fn after_start<F, Fut>(self, hook: F) -> App<Built, C>
pub fn after_start<F, Fut>(self, hook: F) -> App<Built, C>
Register a hook called after components start and readiness checks pass.
Sourcepub fn before_stop<F, Fut>(self, hook: F) -> App<Built, C>
pub fn before_stop<F, Fut>(self, hook: F) -> App<Built, C>
Register a hook called before components stop.
Sourceimpl<C> App<Built, C>where
C: AppConfig,
impl<C> App<Built, C>where
C: AppConfig,
Sourceimpl<C> App<Started, C>
impl<C> App<Started, C>
Sourcepub fn lifecycle_event_bus(&self) -> EventBus<LifecycleEvent>
pub fn lifecycle_event_bus(&self) -> EventBus<LifecycleEvent>
Return the bounded lifecycle event bus used by this app.
Sourcepub fn shutdown_token(&self) -> CancellationToken
pub fn shutdown_token(&self) -> CancellationToken
Clone the shutdown token to share with long-running tasks.